pub struct Error {
pub message: String,
}Expand description
A LevelDB error, just containing the error string provided by LevelDB.
Fields
message: StringImplementations
Sourceimpl Error
impl Error
Sourcepub unsafe fn new_from_char(message: *const c_char) -> Error
pub unsafe fn new_from_char(message: *const c_char) -> Error
create an error from a c-string buffer.
This method is unsafe because the pointer must be valid and point to heap.
The pointer will be passed to free!
Safety
The caller must ensure that:
messageis a valid pointer to a null-terminated C string- The C string is valid UTF-8
- The memory pointed to by
messagewas allocated by LevelDB and can be safely freed