pub struct BoundedKeyPolicy<'a> { /* private fields */ }Expand description
Policy for bounded key iteration with from/to bounds.
This policy restricts iteration to a specific key range.
Important: When using BoundedKeyPolicy, the method seek() must be called explicitly
before starting iteration. This policy does not automatically seek to the beginning position.
Implementations