pub struct Iterator<'a, T = KeyType, D = Forward, P = DefaultPolicy> { /* private fields */ }Expand description
A fully unified iterator over the LevelDB keyspace.
The iteration direction is determined by the generic parameters D.
The return type is determined by the generic parameters T.
The iteration policy is determined by parameter P.
This provides static dispatch for direction-specific, type-specific, and policy-specific operations.
Implementations
Sourceimpl<'a, P: Policy> Iterator<'a, KeyType, Forward, P>
impl<'a, P: Policy> Iterator<'a, KeyType, Forward, P>
Sourcepub fn last(&mut self) -> Result<Option<Slice<'a>>, Error>
pub fn last(&mut self) -> Result<Option<Slice<'a>>, Error>
Return the last element of the iterator
The returned slice borrows data directly from the LevelDB iterator without copying. The data is only valid until the iterator is advanced to the next position or destroyed.
Safety
The caller must ensure that the returned slice does not outlive the iterator
or any operation that would advance the iterator (such as calling next()).
To keep the data longer, the slice should be cloned.
Performance
This method provides zero-copy access to LevelDB data for maximum performance
Sourceimpl<'a, P: Policy> Iterator<'a, ValueType, Forward, P>
impl<'a, P: Policy> Iterator<'a, ValueType, Forward, P>
Sourcepub fn last(&mut self) -> Result<Option<Slice<'a>>, Error>
pub fn last(&mut self) -> Result<Option<Slice<'a>>, Error>
Return the last element of the iterator
The returned slice borrows data directly from the LevelDB iterator without copying. The data is only valid until the iterator is advanced to the next position or destroyed.
Safety
The caller must ensure that the returned slice does not outlive the iterator
or any operation that would advance the iterator (such as calling next()).
To keep the data longer, the slice should be cloned.
Performance
This method provides zero-copy access to LevelDB data for maximum performance
Sourceimpl<'a, P: Policy> Iterator<'a, EntryType, Forward, P>
impl<'a, P: Policy> Iterator<'a, EntryType, Forward, P>
Sourcepub fn last(&mut self) -> Result<Option<(Slice<'a>, Slice<'a>)>, Error>
pub fn last(&mut self) -> Result<Option<(Slice<'a>, Slice<'a>)>, Error>
Return the last element of the iterator
The returned slice borrows data directly from the LevelDB iterator without copying. The data is only valid until the iterator is advanced to the next position or destroyed.
Safety
The caller must ensure that the returned slice does not outlive the iterator
or any operation that would advance the iterator (such as calling next()).
To keep the data longer, the slice should be cloned.
Performance
This method provides zero-copy access to LevelDB data for maximum performance
Sourceimpl<'a, P: Policy> Iterator<'a, KeyType, Backward, P>
impl<'a, P: Policy> Iterator<'a, KeyType, Backward, P>
Sourcepub fn last(&mut self) -> Result<Option<Slice<'a>>, Error>
pub fn last(&mut self) -> Result<Option<Slice<'a>>, Error>
Return the last element of the iterator
The returned slice borrows data directly from the LevelDB iterator without copying. The data is only valid until the iterator is advanced to the next position or destroyed.
Safety
The caller must ensure that the returned slice does not outlive the iterator
or any operation that would advance the iterator (such as calling next()).
To keep the data longer, the slice should be cloned.
Performance
This method provides zero-copy access to LevelDB data for maximum performance
Sourceimpl<'a, P: Policy> Iterator<'a, ValueType, Backward, P>
impl<'a, P: Policy> Iterator<'a, ValueType, Backward, P>
Sourcepub fn last(&mut self) -> Result<Option<Slice<'a>>, Error>
pub fn last(&mut self) -> Result<Option<Slice<'a>>, Error>
Return the last element of the iterator
The returned slice borrows data directly from the LevelDB iterator without copying. The data is only valid until the iterator is advanced to the next position or destroyed.
Safety
The caller must ensure that the returned slice does not outlive the iterator
or any operation that would advance the iterator (such as calling next()).
To keep the data longer, the slice should be cloned.
Performance
This method provides zero-copy access to LevelDB data for maximum performance
Sourceimpl<'a, P: Policy> Iterator<'a, EntryType, Backward, P>
impl<'a, P: Policy> Iterator<'a, EntryType, Backward, P>
Sourcepub fn last(&mut self) -> Result<Option<(Slice<'a>, Slice<'a>)>, Error>
pub fn last(&mut self) -> Result<Option<(Slice<'a>, Slice<'a>)>, Error>
Return the last element of the iterator
The returned slice borrows data directly from the LevelDB iterator without copying. The data is only valid until the iterator is advanced to the next position or destroyed.
Safety
The caller must ensure that the returned slice does not outlive the iterator
or any operation that would advance the iterator (such as calling next()).
To keep the data longer, the slice should be cloned.
Performance
This method provides zero-copy access to LevelDB data for maximum performance