BoundedKeyPolicy

Struct BoundedKeyPolicy 

pub struct BoundedKeyPolicy<'a> { /* private fields */ }
Policy for bounded key iteration with from/to bounds.

This policy restricts iteration to a specific key range.

Important: When using BoundedKeyPolicy, the method seek() must be called explicitly before starting iteration. This policy does not automatically seek to the beginning position.

Implementations

Source

impl<'a> BoundedKeyPolicy<'a>

pub fn new(from: Option<Slice<'a>>, to: Option<Slice<'a>>) -> Self