pub struct ReadOptions {
pub verify_checksums: bool,
pub fill_cache: bool,
}Expand description
The read options to use for any read operation.
Fields
verify_checksums: boolWhether to verify the saved checksums on read.
default: false
fill_cache: boolWhether to fill the internal cache with the results of the read.
default: true
Implementations
Sourceimpl ReadOptions
impl ReadOptions
Sourcepub fn new() -> ReadOptions
pub fn new() -> ReadOptions
Return a ReadOptions struct with the default values.